@@ -3,7 +3,7 @@ from .confluence_reporter import ConfluenceReporter
 from .plotly_reporter import PlotlyReporter
 from .csv_parser import CSVParser
 from .at_coverage_reporter import ATCoverageReporter
-from .reporter_utils import format_error
 from .case_stat import CaseStat
 from .email_sender import EmailSender
 from .slack_sender import SlackSender
+from .reporter_utils import format_error, upload_image
\ No newline at end of file
